@@ -41,6 +41,7 @@ func (d *drainerMockOwned) Drain(ctx context.Context, input *nodegroup.DrainInpu
 var _ = Describe("Delete", func() {
 	var (
 		clusterName              string
+		ctx                      context.Context
 		p                        *mockprovider.MockProvider
 		cfg                      *api.ClusterConfig
 		fakeStackManager         *fakes.FakeStackManager
@@ -52,6 +53,7 @@ var _ = Describe("Delete", func() {
 
 	BeforeEach(func() {
 		clusterName = "my-cluster"
+		ctx = context.Background()
 		p = mockprovider.NewMockProvider()
 		cfg = api.NewClusterConfig()
 		cfg.Metadata.Name = clusterName
@@ -112,7 +114,8 @@ var _ = Describe("Delete", func() {
 
 			fakeStackManager.GetKarpenterStackReturns(karpenterStack, nil)
 
-			c := cluster.NewOwnedCluster(cfg, ctl, nil, fakeStackManager)
+			c, err := cluster.NewOwnedCluster(ctx, cfg, ctl, nil, fakeStackManager)
+			Expect(err).NotTo(HaveOccurred())
 			fakeClientSet = fake.NewSimpleClientset()
 
 			c.SetNewClientSet(func() (kubernetes.Interface, error) {
@@ -124,7 +127,7 @@ var _ = Describe("Delete", func() {
 				return mockedDrainer
 			})
 
-			err := c.Delete(context.Background(), time.Microsecond, 0, false, false, false, 1)
+			err = c.Delete(context.Background(), time.Microsecond, 0, false, false, false, 1)
 			Expect(err).NotTo(HaveOccurred())
 			Expect(fakeStackManager.DeleteTasksForDeprecatedStacksCallCount()).To(Equal(1))
 			Expect(ranDeleteDeprecatedTasks).To(BeTrue())
@@ -180,7 +183,8 @@ var _ = Describe("Delete", func() {
 					Tasks: []tasks.Task{},
 				}, nil)
 
-				c := cluster.NewOwnedCluster(cfg, ctl, nil, fakeStackManager)
+				c, err := cluster.NewOwnedCluster(ctx, cfg, ctl, nil, fakeStackManager)
+				Expect(err).NotTo(HaveOccurred())
 				fakeClientSet = fake.NewSimpleClientset()
 
 				c.SetNewClientSet(func() (kubernetes.Interface, error) {
@@ -199,7 +203,7 @@ var _ = Describe("Delete", func() {
 					return mockedDrainer
 				})
 
-				err := c.Delete(context.Background(), time.Microsecond, 0, false, true, false, 1)
+				err = c.Delete(context.Background(), time.Microsecond, 0, false, true, false, 1)
 				Expect(err).NotTo(HaveOccurred())
 				Expect(fakeStackManager.DeleteTasksForDeprecatedStacksCallCount()).To(Equal(1))
 				Expect(ranDeleteDeprecatedTasks).To(BeFalse())
@@ -245,7 +249,8 @@ var _ = Describe("Delete", func() {
 					Tasks: []tasks.Task{},
 				}, nil)
 
-				c := cluster.NewOwnedCluster(cfg, ctl, nil, fakeStackManager)
+				c, err := cluster.NewOwnedCluster(ctx, cfg, ctl, nil, fakeStackManager)
+				Expect(err).NotTo(HaveOccurred())
 				fakeClientSet = fake.NewSimpleClientset()
 
 				c.SetNewClientSet(func() (kubernetes.Interface, error) {
@@ -272,7 +277,7 @@ var _ = Describe("Delete", func() {
 					return mockedDrainer
 				})
 
-				err := c.Delete(context.Background(), time.Microsecond, time.Second*0, false, false, false, 1)
+				err = c.Delete(context.Background(), time.Microsecond, time.Second*0, false, false, false, 1)
 				Expect(err).To(MatchError(errorMessage))
 				Expect(fakeStackManager.DeleteTasksForDeprecatedStacksCallCount()).To(Equal(0))
 				Expect(ranDeleteDeprecatedTasks).To(BeFalse())
@@ -315,7 +320,8 @@ var _ = Describe("Delete", func() {
 				}}},
 			}, nil)
 
-			c := cluster.NewOwnedCluster(cfg, ctl, nil, fakeStackManager)
+			c, err := cluster.NewOwnedCluster(ctx, cfg, ctl, nil, fakeStackManager)
+			Expect(err).NotTo(HaveOccurred())
 			c.SetNewNodeGroupManager(func(cfg *api.ClusterConfig, ctl *eks.ClusterProvider, clientSet kubernetes.Interface) cluster.NodeGroupDrainer {
 				mockedDrainer := &drainerMockOwned{}
 				mockedDrainer.On("Drain", mock.Anything).Return(nil)
@@ -325,7 +331,7 @@ var _ = Describe("Delete", func() {
 				return fake.NewSimpleClientset(), nil
 			})
 
-			err := c.Delete(context.Background(), time.Microsecond, time.Second*0, false, false, false, 1)
+			err = c.Delete(context.Background(), time.Microsecond, time.Second*0, false, false, false, 1)
 			Expect(err).NotTo(HaveOccurred())
 			Expect(fakeStackManager.DeleteTasksForDeprecatedStacksCallCount()).To(Equal(1))
 			Expect(ranDeleteDeprecatedTasks).To(BeTrue())
