@@ -1,23 +1,27 @@
 package identityproviders
 
 import (
-	"github.com/aws/aws-sdk-go/service/eks/eksiface"
+	"context"
+
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
+	"github.com/weaveworks/eksctl/pkg/awsapi"
 	"github.com/weaveworks/eksctl/pkg/utils/tasks"
 )
 
 type AssociateProvidersTask struct {
 	metadata  api.ClusterMeta
 	providers []api.IdentityProvider
-	eks       eksiface.EKSAPI
+	eks       awsapi.EKS
+	ctx       context.Context
 }
 
-func NewAssociateProvidersTask(metadata api.ClusterMeta, providers []api.IdentityProvider, eks eksiface.EKSAPI) tasks.Task {
+func NewAssociateProvidersTask(ctx context.Context, metadata api.ClusterMeta, providers []api.IdentityProvider, eks awsapi.EKS) tasks.Task {
 	return tasks.SynchronousTask{
 		SynchronousTaskIface: &AssociateProvidersTask{
 			metadata:  metadata,
 			providers: providers,
 			eks:       eks,
+			ctx:       ctx,
 		},
 	}
 }
@@ -28,5 +32,5 @@ func (t *AssociateProvidersTask) Describe() string {
 
 func (t *AssociateProvidersTask) Do() error {
 	m := NewManager(t.metadata, t.eks)
-	return m.Associate(AssociateIdentityProvidersOptions{Providers: t.providers})
+	return m.Associate(t.ctx, AssociateIdentityProvidersOptions{Providers: t.providers})
 }
