@@ -3,18 +3,13 @@ package helm
 import (
 	"context"
 	"fmt"
-	"io/ioutil"
-	"os"
-	"path/filepath"
 	"time"
 
 	"github.com/kris-nova/logger"
-	"gopkg.in/yaml.v1"
 	"helm.sh/helm/v3/pkg/action"
 	"helm.sh/helm/v3/pkg/chart/loader"
 	"helm.sh/helm/v3/pkg/cli"
 	"helm.sh/helm/v3/pkg/getter"
-	"helm.sh/helm/v3/pkg/repo"
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 
 	"github.com/weaveworks/eksctl/pkg/karpenter/providers"
@@ -49,42 +44,10 @@ func NewInstaller(opts Options) (*Installer, error) {
 
 var _ providers.HelmInstaller = &Installer{}
 
-// AddRepo adds a repository to helm repositories.
-func (i *Installer) AddRepo(repoURL, release string) error {
-	if err := os.MkdirAll(filepath.Dir(i.Settings.RegistryConfig), os.ModePerm); err != nil && !os.IsExist(err) {
-		return fmt.Errorf("failed to make cache folder: %w", err)
-	}
-	b, err := ioutil.ReadFile(i.Settings.RegistryConfig)
-	if err != nil && !os.IsNotExist(err) {
-		return fmt.Errorf("failed to read registry file: %w", err)
-	}
-
-	var f repo.File
-	if err := yaml.Unmarshal(b, &f); err != nil {
-		return fmt.Errorf("failed to marshal repo file: %w", err)
-	}
-
-	c := repo.Entry{
-		Name: release,
-		URL:  repoURL,
-	}
-	r, err := repo.NewChartRepository(&c, i.Getters)
-	if err != nil {
-		return fmt.Errorf("failed to create new chart repository: %w", err)
-	}
-	if _, err := r.DownloadIndexFile(); err != nil {
-		return fmt.Errorf("failed to download index file: %w", err)
-	}
-	f.Update(&c)
-	if err := f.WriteFile(i.Settings.RepositoryConfig, 0644); err != nil {
-		return fmt.Errorf("failed to write out repository config file: %w", err)
-	}
-	return nil
-}
-
 // InstallChart takes a repo's name and a chart name and installs it. If namespace is not empty
 // it will install into that namespace and create the namespace. Version is required.
 func (i *Installer) InstallChart(ctx context.Context, opts providers.InstallChartOpts) error {
+	i.ActionConfig.RegistryClient = opts.RegistryClient
 	client := action.NewInstall(i.ActionConfig)
 	client.Wait = true
 	client.Namespace = opts.Namespace
@@ -108,6 +71,6 @@ func (i *Installer) InstallChart(ctx context.Context, opts providers.InstallChar
 	if err != nil {
 		return fmt.Errorf("failed to install chart: %w", err)
 	}
-	logger.Debug("successfully installed helm chart: %s", release.Name)
+	logger.Debug("successfully installed %s helm chart: %s/%s", release.Name, opts.ChartName, opts.Version)
 	return nil
 }
